@@ -14,11 +14,11 @@ DBIx::Class::Result::Validation - DBIx::Class component to manage validation on
 
 =head1 VERSION
 
-Version 0.13
+Version 0.14
 
 =cut
 
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 
 =head1 SYNOPSIS
 
@@ -107,6 +107,39 @@ You can redefined it in your Result object and call back it with  :
 sub validate {
   my $self = shift;
   $self->_erase_result_error();
+  my @columns = $self->result_source->columns;
+  foreach my $field (@columns)
+  {
+      if ($self->result_source->column_info($field)->{'validation'})
+      {
+          my $validations;
+          #convert every sources of validation in array
+          if ( ref($self->result_source->column_info($field)->{'validation'}) ne 'ARRAY'){
+            push @{$validations},$self->result_source->column_info($field)->{'validation'};
+          }
+          else{
+             $validations = $self->result_source->column_info($field)->{'validation'};
+          }
+          if ( scalar(@{$validations}) >0 ){
+              foreach my $validation (@{$validations}){
+                  my $validation_function = "validate_" . $validation;
+                  #Unvalid validation method cause a croak exception
+                  try{
+                     $self->$validation_function($field);
+                  }
+                  catch{
+                      croak(
+                              DBIx::Class::Result::Validation::VException->new(
+                                  object  => $self,
+                                  message => "Validation : $validation is not valid"
+                                  )
+                           );
+                  }
+              }
+          }
+      }
+  }
+
   $self->_validate();
   return 0 if (defined $self->result_errors);
   return 1;
@@ -165,6 +198,7 @@ Insert is done only if validate method return true
 
 sub insert {
     my $self = shift;
+
     my $insert = $self->next::can;
     return $self->_try_next_method($self->next::can, @_);
 }
@@ -239,6 +273,70 @@ sub _erase_result_error
     $self->result_errors(undef);
 }
 
+
+=head1 VALIDATION METHOD
+
+set of function to validate fields
+
+=cut
+
+=head2 validate_enum function
+
+validation of the enum field, should return a validation error if the field is set and is not in the list of enum
+
+=cut
+
+sub validate_enum {
+    my ($self, $field) = @_;
+    $self->add_result_error( $field, $field ." must be set with one of the following value: " .join(", ", @{$self->result_source->columns_info->{$field}->{extra}->{list}}) )
+    if( 
+            (!defined ($self->$field) && !defined($self->result_source->columns_info->{$field}->{default_value})
+            or  
+            (defined ($self->$field) && !($self->$field ~~ @{ $self->result_source->columns_info->{$field}->{extra}->{list} }))
+      )
+    );
+}
+
+=head2 validate_defined
+
+validation of field which must be defined, return error if the field is not defined
+
+=cut
+
+sub validate_defined {
+    my ($self, $field) = @_;
+
+    $self->add_result_error( $field, "must be set" )
+      unless defined $self->$field;
+}
+
+=head2 validate_not_empty
+
+validation of a field which can be null but can't be empty
+
+=cut
+
+sub validate_not_empty {
+    my ($self, $field) = @_;
+
+    $self->add_result_error( $field, "can not be empty" )
+      if defined $self->$field && $self->$field eq '';
+}
+
+=head2 validate_not_null_or_not_zero
+
+validation of a field which can be null and not equal to 0
+this can be used for data_type integer
+
+=cut
+
+sub validate_not_null_or_not_zero {
+    my ($self, $field) = @_;
+
+    $self->add_result_error( $field, "can not be null or equal to 0" )
+      if !$self->$field;
+}
+
 1;
 __END__
 
